#include "./Renderer.h"
#include "./Display.h"

#include <ArduinoLog.h>

void
Renderer::loop()
{
    for(Display* dpy : m_displays) {
        for(Figment* figment : m_figments) {
            if (figment->state == Task::Running) {
#if defined(BOARD_ESP32) or defined(BOARD_ESP8266)
                unsigned int frameStart = ESP.getCycleCount();
#endif
                Log.verbose("Render %s", figment->name);
                figment->render(dpy);
#if defined(BOARD_ESP32) or defined(BOARD_ESP8266)
                unsigned int runtime = (ESP.getCycleCount() - frameStart) / 160000;
#else
                unsigned int runtime = 0;
#endif
                if (runtime >= 8) {
                  Log.warning("SLOW RENDER: %s took %dms!", figment->name, runtime);
                }
            }
        };
    }
    FastLED.show();
    FastLED.countFPS();
}

void
Renderer::onStart()
{
    for(Display* dpy : m_displays) {
        dpy->clear();
    }
    FastLED.show();
}
